@@ -1,12 +1,12 @@
-__version__ = "0.9.27"
+__version__ = "0.10.0"
 
 
-# amalgamate exclude jupyter_kernel parser_table parser_test_table pyghooks
+# amalgamate exclude jupyter_kernel parser_table completion_parser_table parser_test_table pyghooks
 # amalgamate exclude winutils wizard pytest_plugin fs macutils pygments_cache
-# amalgamate exclude jupyter_shell proc
+# amalgamate exclude jupyter_shell proc built_ins
 import os as _os
 
-if _os.getenv("XONSH_DEBUG", ""):
+if _os.getenv("XONSH_NO_AMALGAMATE", ""):
     pass
 else:
     import sys as _sys
@@ -46,8 +46,6 @@ else:
         _sys.modules["xonsh.commands_cache"] = __amalgam__
         completer = __amalgam__
         _sys.modules["xonsh.completer"] = __amalgam__
-        diff_history = __amalgam__
-        _sys.modules["xonsh.diff_history"] = __amalgam__
         events = __amalgam__
         _sys.modules["xonsh.events"] = __amalgam__
         foreign_shells = __amalgam__
@@ -64,8 +62,12 @@ else:
         _sys.modules["xonsh.xontribs"] = __amalgam__
         ansi_colors = __amalgam__
         _sys.modules["xonsh.ansi_colors"] = __amalgam__
+        diff_history = __amalgam__
+        _sys.modules["xonsh.diff_history"] = __amalgam__
         dirstack = __amalgam__
         _sys.modules["xonsh.dirstack"] = __amalgam__
+        execer = __amalgam__
+        _sys.modules["xonsh.execer"] = __amalgam__
         shell = __amalgam__
         _sys.modules["xonsh.shell"] = __amalgam__
         style_tools = __amalgam__
@@ -78,24 +80,20 @@ else:
         _sys.modules["xonsh.base_shell"] = __amalgam__
         environ = __amalgam__
         _sys.modules["xonsh.environ"] = __amalgam__
+        imphooks = __amalgam__
+        _sys.modules["xonsh.imphooks"] = __amalgam__
         inspectors = __amalgam__
         _sys.modules["xonsh.inspectors"] = __amalgam__
         aliases = __amalgam__
         _sys.modules["xonsh.aliases"] = __amalgam__
+        main = __amalgam__
+        _sys.modules["xonsh.main"] = __amalgam__
         readline_shell = __amalgam__
         _sys.modules["xonsh.readline_shell"] = __amalgam__
         tracer = __amalgam__
         _sys.modules["xonsh.tracer"] = __amalgam__
-        built_ins = __amalgam__
-        _sys.modules["xonsh.built_ins"] = __amalgam__
         dumb_shell = __amalgam__
         _sys.modules["xonsh.dumb_shell"] = __amalgam__
-        execer = __amalgam__
-        _sys.modules["xonsh.execer"] = __amalgam__
-        imphooks = __amalgam__
-        _sys.modules["xonsh.imphooks"] = __amalgam__
-        main = __amalgam__
-        _sys.modules["xonsh.main"] = __amalgam__
         del __amalgam__
     except ImportError:
         pass
