@@ -4,8 +4,8 @@ import io
 import os
 import sys
 import time
-import builtins
 
+from xonsh.built_ins import XSH
 from xonsh.tools import (
     XonshError,
     print_exception,
@@ -66,7 +66,7 @@ class _TeeStdBuf(io.RawIOBase):
         """
         self.stdbuf = stdbuf
         self.membuf = membuf
-        env = builtins.__xonsh__.env
+        env = XSH.env
         self.encoding = env.get("XONSH_ENCODING") if encoding is None else encoding
         self.errors = env.get("XONSH_ENCODING_ERRORS") if errors is None else errors
         self.prestd = prestd
@@ -268,7 +268,7 @@ class Tee:
             write_through=write_through,
         )
         self.stdout = _TeeStd("stdout", self.memory)
-        env = builtins.__xonsh__.env
+        env = XSH.env
         prestderr = format_std_prepost(env.get("XONSH_STDERR_PREFIX"))
         poststderr = format_std_prepost(env.get("XONSH_STDERR_POSTFIX"))
         self.stderr = _TeeStd(
@@ -314,6 +314,9 @@ class BaseShell(object):
         self._styler = DefaultNotGiven
         self.prompt_formatter = PromptFormatter()
         self.accumulated_inputs = ""
+        self.precwd = (
+            None  # The current working directory just before execution of the line
+        )
 
     @property
     def styler(self):
@@ -321,7 +324,7 @@ class BaseShell(object):
             if HAS_PYGMENTS:
                 from xonsh.pyghooks import XonshStyle
 
-                env = builtins.__xonsh__.env
+                env = XSH.env
                 self._styler = XonshStyle(env.get("XONSH_COLOR_STYLE"))
             else:
                 self._styler = None
@@ -347,6 +350,7 @@ class BaseShell(object):
 
     def precmd(self, line):
         """Called just before execution of line."""
+        self.precwd = os.getcwd()
         return line if self.need_more_lines else line.lstrip()
 
     def default(self, line, raw_line=None):
@@ -363,14 +367,14 @@ class BaseShell(object):
 
         events.on_precommand.fire(cmd=src)
 
-        env = builtins.__xonsh__.env
-        hist = builtins.__xonsh__.history  # pylint: disable=no-member
+        env = XSH.env
+        hist = XSH.history  # pylint: disable=no-member
         ts1 = None
         enc = env.get("XONSH_ENCODING")
         err = env.get("XONSH_ENCODING_ERRORS")
         tee = Tee(encoding=enc, errors=err)
+        ts0 = time.time()
         try:
-            ts0 = time.time()
             run_compiled_code(code, self.ctx, None, "single")
             ts1 = time.time()
             if hist is not None and hist.last_cmd_rtn is None:
@@ -391,6 +395,7 @@ class BaseShell(object):
                 ts=[ts0, ts1],
                 spc=self.src_starts_with_space,
                 tee_out=tee_out,
+                cwd=self.precwd,
             )
             self.accumulated_inputs += src
             if (
@@ -401,7 +406,7 @@ class BaseShell(object):
                 print(os.linesep, end="")
             tee.close()
             self._fix_cwd()
-        if builtins.__xonsh__.exit:  # pylint: disable=no-member
+        if XSH.exit:  # pylint: disable=no-member
             return True
 
     def _append_history(self, tee_out=None, **info):
@@ -410,7 +415,7 @@ class BaseShell(object):
         This also handles on_postcommand because this is the place where all the
         information is available.
         """
-        hist = builtins.__xonsh__.history  # pylint: disable=no-member
+        hist = XSH.history  # pylint: disable=no-member
         info["rtn"] = hist.last_cmd_rtn if hist is not None else None
         tee_out = tee_out or None
         last_out = hist.last_cmd_out if hist is not None else None
@@ -431,10 +436,10 @@ class BaseShell(object):
 
     def _fix_cwd(self):
         """Check if the cwd changed out from under us."""
-        env = builtins.__xonsh__.env
+        env = XSH.env
         try:
             cwd = os.getcwd()
-        except (FileNotFoundError, OSError):
+        except OSError:
             cwd = None
         if cwd is None:
             # directory has been deleted out from under us, most likely
@@ -518,7 +523,7 @@ class BaseShell(object):
 
     def settitle(self):
         """Sets terminal title."""
-        env = builtins.__xonsh__.env  # pylint: disable=no-member
+        env = XSH.env  # pylint: disable=no-member
         term = env.get("TERM", None)
         # Shells running in emacs sets TERM to "dumb" or "eterm-color".
         # Do not set title for these to avoid garbled prompt.
@@ -552,7 +557,7 @@ class BaseShell(object):
                     print_exception()
                     self.mlprompt = "<multiline prompt error> "
             return self.mlprompt
-        env = builtins.__xonsh__.env  # pylint: disable=no-member
+        env = XSH.env  # pylint: disable=no-member
         p = env.get("PROMPT")
         try:
             p = self.prompt_formatter(p)
@@ -565,7 +570,7 @@ class BaseShell(object):
         """Formats the colors in a string. ``BaseShell``'s default implementation
         of this method uses colors based on ANSI color codes.
         """
-        style = builtins.__xonsh__.env.get("XONSH_COLOR_STYLE")
+        style = XSH.env.get("XONSH_COLOR_STYLE")
         return ansi_partial_color_format(string, hide=hide, style=style)
 
     def print_color(self, string, hide=False, **kwargs):
@@ -578,7 +583,7 @@ class BaseShell(object):
             s = self.format_color(string, hide=hide)
         elif HAS_PYGMENTS:
             # assume this is a list of (Token, str) tuples and format it
-            env = builtins.__xonsh__.env
+            env = XSH.env
             self.styler.style_name = env.get("XONSH_COLOR_STYLE")
             style_proxy = pyghooks.xonsh_style_proxy(self.styler)
             formatter = pyghooks.XonshTerminal256Formatter(style=style_proxy)
