@@ -10,6 +10,7 @@ from collections.abc import MutableMapping
 from keyword import iskeyword
 import typing as tp
 
+from xonsh.built_ins import XSH
 from xonsh.lazyimps import os_listxattr
 
 from pygments.lexer import inherit, bygroups, include
@@ -52,7 +53,7 @@ from xonsh.color_tools import (
     iscolor,
     warn_deprecated_no_color,
 )
-from xonsh.style_tools import norm_name
+from xonsh.style_tools import norm_name, DEFAULT_STYLE_DICT
 from xonsh.lazyimps import terminal256, html
 from xonsh.platform import (
     os_environ,
@@ -72,6 +73,26 @@ from xonsh.events import events
 
 Color = Token.Color  # alias to new color token namespace
 
+# style rules that are not supported by pygments are stored here
+NON_PYGMENTS_RULES: tp.Dict[str, tp.Dict[str, str]] = {}
+
+# style modifiers not handled by pygments (but supported by ptk)
+PTK_SPECIFIC_VALUES = frozenset(
+    {"reverse", "noreverse", "hidden", "nohidden", "blink", "noblink"}
+)
+
+# Generate fallback style dict from non-pygments styles
+# (Let pygments handle the defaults where it can)
+FALLBACK_STYLE_DICT = LazyObject(
+    lambda: {
+        token: value
+        for token, value in DEFAULT_STYLE_DICT.items()
+        if str(token).startswith("Token.PTK")
+    },
+    globals(),
+    "FALLBACK_STYLE_DICT",
+)
+
 
 def color_by_name(name, fg=None, bg=None):
     """Converts a color name to a color token, foreground name,
@@ -222,7 +243,7 @@ def color_token_by_name(xc: tuple, styles=None) -> _TokenType:
     """Returns (color) token corresponding to Xonsh color tuple, side effect: defines token is defined in styles"""
     if not styles:
         try:
-            styles = builtins.__xonsh__.shell.shell.styler.styles  # type:ignore
+            styles = XSH.shell.shell.styler.styles  # type:ignore
         except AttributeError:
             return Color
 
@@ -234,7 +255,7 @@ def color_token_by_name(xc: tuple, styles=None) -> _TokenType:
         tokName += "__" + xc[1]
 
     token = getattr(Color, norm_name(tokName))
-    if token not in styles:
+    if token not in styles or not styles[token]:
         styles[token] = pc
     return token
 
@@ -244,7 +265,7 @@ def partial_color_tokenize(template):
     of tuples mapping the token to the string which has that color.
     These sub-strings maybe templates themselves.
     """
-    if builtins.__xonsh__.shell is not None:
+    if XSH.shell is not None:
         styles = __xonsh__.shell.shell.styler.styles
     else:
         styles = None
@@ -370,7 +391,7 @@ class XonshStyle(Style):
                     file=sys.stderr,
                 )
                 value = "default"
-                builtins.__xonsh__.env["XONSH_COLOR_STYLE"] = value
+                XSH.env["XONSH_COLOR_STYLE"] = value
         cmap = STYLES[value]
         if value == "default":
             self._smap = XONSH_BASE_STYLE.copy()
@@ -382,29 +403,39 @@ class XonshStyle(Style):
                 self.background_color = style_obj.background_color
             except (ImportError, pygments.util.ClassNotFound):
                 self._smap = XONSH_BASE_STYLE.copy()
-        compound = CompoundColorMap(ChainMap(self.trap, cmap, PTK_STYLE, self._smap))
-        self.styles = ChainMap(self.trap, cmap, PTK_STYLE, self._smap, compound)
+
+        compound = CompoundColorMap(
+            ChainMap(self.trap, cmap, self._smap, FALLBACK_STYLE_DICT)
+        )
+        self.styles = ChainMap(
+            self.trap, cmap, self._smap, FALLBACK_STYLE_DICT, compound
+        )
         self._style_name = value
 
-        for file_type, xonsh_color in builtins.__xonsh__.env.get(
-            "LS_COLORS", {}
-        ).items():
+        for file_type, xonsh_color in XSH.env.get("LS_COLORS", {}).items():
             color_token = color_token_by_name(xonsh_color, self.styles)
             file_color_tokens[file_type] = color_token
 
-        if ON_WINDOWS and "prompt_toolkit" in builtins.__xonsh__.shell.shell_type:
+        if ON_WINDOWS and "prompt_toolkit" in XSH.shell.shell_type:
             self.enhance_colors_for_cmd_exe()
 
     @style_name.deleter
     def style_name(self):
         self._style_name = ""
 
+    @property
+    def non_pygments_rules(self):
+        return NON_PYGMENTS_RULES.get(self.style_name, {})
+
+    def override(self, style_dict):
+        self.trap.update(_tokenize_style_dict(style_dict))
+
     def enhance_colors_for_cmd_exe(self):
-        """ Enhance colors when using cmd.exe on windows.
-            When using the default style all blue and dark red colors
-            are changed to CYAN and intense red.
+        """Enhance colors when using cmd.exe on windows.
+        When using the default style all blue and dark red colors
+        are changed to CYAN and intense red.
         """
-        env = builtins.__xonsh__.env
+        env = XSH.env
         # Ensure we are not using the new Windows Terminal, ConEmu or Visual Stuio Code
         if "WT_SESSION" in env or "CONEMUANSI" in env or "VSCODE_PID" in env:
             return
@@ -438,24 +469,56 @@ def xonsh_style_proxy(styler):
     return XonshStyleProxy
 
 
+def _ptk_specific_style_value(style_value):
+    """Checks if the given value is PTK style specific"""
+    for ptk_spec in PTK_SPECIFIC_VALUES:
+        if ptk_spec in style_value:
+            return True
+
+    return False
+
+
+def _format_ptk_style_name(name):
+    """Format PTK style name to be able to include it in a pygments style"""
+    parts = name.split("-")
+    return "".join(part.capitalize() for part in parts)
+
+
 def _get_token_by_name(name):
     """Get pygments token object by its string representation."""
+    if not isinstance(name, str):
+        return name
+
     token = Token
     parts = name.split(".")
 
+    # PTK - all lowercase
+    if parts[0] == parts[0].lower():
+        parts = ["PTK"] + [_format_ptk_style_name(part) for part in parts]
+
+    # color name
     if len(parts) == 1:
-        parts = ["Color"] + parts
+        return color_token_by_name((name,))
 
     if parts[0] == "Token":
         parts = parts[1:]
 
-    while len(parts):
+    while len(parts) > 0:
         token = getattr(token, parts[0])
         parts = parts[1:]
 
     return token
 
 
+def _tokenize_style_dict(styles):
+    """Converts possible string keys in style dicts to Tokens"""
+    return {
+        _get_token_by_name(token): value
+        for token, value in styles.items()
+        if not _ptk_specific_style_value(value)
+    }
+
+
 def register_custom_pygments_style(
     name, styles, highlight_color=None, background_color=None, base="default"
 ):
@@ -481,11 +544,15 @@ def register_custom_pygments_style(
     base_style = get_style_by_name(base)
     custom_styles = base_style.styles.copy()
 
-    for token, value in styles.items():
-        if isinstance(token, str):
-            token = _get_token_by_name(token)
+    for token, value in _tokenize_style_dict(styles).items():
         custom_styles[token] = value
 
+    non_pygments_rules = {
+        token: value
+        for token, value in styles.items()
+        if _ptk_specific_style_value(value)
+    }
+
     style = type(
         f"Custom{name}Style",
         (Style,),
@@ -510,26 +577,12 @@ def register_custom_pygments_style(
             cmap[token] = custom_styles[token]
 
     STYLES[name] = cmap
+    if len(non_pygments_rules) > 0:
+        NON_PYGMENTS_RULES[name] = non_pygments_rules
 
     return style
 
 
-PTK_STYLE = LazyObject(
-    lambda: {
-        Token.Menu.Completions: "bg:ansigray ansiblack",
-        Token.Menu.Completions.Completion: "",
-        Token.Menu.Completions.Completion.Current: "bg:ansibrightblack ansiwhite",
-        Token.Scrollbar: "bg:ansibrightblack",
-        Token.Scrollbar.Button: "bg:ansiblack",
-        Token.Scrollbar.Arrow: "bg:ansiblack ansiwhite bold",
-        Token.AutoSuggestion: "ansibrightblack",
-        Token.Aborted: "ansibrightblack",
-    },
-    globals(),
-    "PTK_STYLE",
-)
-
-
 XONSH_BASE_STYLE = LazyObject(
     lambda: {
         Whitespace: "ansigray",
@@ -1244,7 +1297,7 @@ del (
 def make_pygments_style(palette):
     """Makes a pygments style based on a color palette."""
     global Color
-    style = {getattr(Color, "DEFAULT"): "noinherit"}
+    style = {Color.DEFAULT: "noinherit"}
     for name, t in BASE_XONSH_COLORS.items():
         color = find_closest_color(t, palette)
         style[getattr(Color, name)] = "#" + color
@@ -1263,8 +1316,8 @@ def pygments_style_by_name(name):
 
 
 def _monkey_patch_pygments_codes():
-    """ Monky patch pygments' dict of console codes,
-        with new color names
+    """Monky patch pygments' dict of console codes,
+    with new color names
     """
     if pygments_version_info() and pygments_version_info() >= (2, 4, 0):
         return
@@ -1313,7 +1366,7 @@ def XonshTerminal256Formatter():
             super().__init__(*args, **kwargs)
             # just keep the opening token for colors.
             color_names = set(map(str, Color.subtypes))
-            for name, (opener, closer) in self.style_string.items():
+            for name, (opener, _) in self.style_string.items():
                 if name in color_names:
                     self.style_string[name] = (opener, "")
             # special case DEFAULT, because it is special.
@@ -1339,7 +1392,7 @@ def XonshHtmlFormatter():
             return ""
         elif text.startswith("var") or text.startswith("calc"):
             return text
-        assert False, "wrong color format %r" % text
+        raise AssertionError("wrong color format %r" % text)
 
     class XonshHtmlFormatterProxy(html.HtmlFormatter):
         """Proxy class for xonsh HTML formatting that understands.
@@ -1446,9 +1499,9 @@ def color_file(file_path: str, path_stat: os.stat_result) -> tp.Tuple[_TokenType
 
     Parameters
     ----------
-    file_path:
+    file_path
         relative path of file (as user typed it).
-    path_stat:
+    path_stat
         lstat() results for file_path.
 
     Returns
@@ -1468,7 +1521,7 @@ def color_file(file_path: str, path_stat: os.stat_result) -> tp.Tuple[_TokenType
          This is arguably a bug.
     """
 
-    lsc = builtins.__xonsh__.env["LS_COLORS"]  # type:ignore
+    lsc = XSH.env["LS_COLORS"]  # type:ignore
     color_key = "fi"
 
     # if symlink, get info on (final) target
@@ -1544,19 +1597,19 @@ def color_file(file_path: str, path_stat: os.stat_result) -> tp.Tuple[_TokenType
 def _command_is_valid(cmd):
     try:
         cmd_abspath = os.path.abspath(os.path.expanduser(cmd))
-    except (FileNotFoundError, OSError):
+    except (OSError):
         return False
-    return (cmd in builtins.__xonsh__.commands_cache and not iskeyword(cmd)) or (
+    return (cmd in XSH.commands_cache and not iskeyword(cmd)) or (
         os.path.isfile(cmd_abspath) and os.access(cmd_abspath, os.X_OK)
     )
 
 
 def _command_is_autocd(cmd):
-    if not builtins.__xonsh__.env.get("AUTO_CD", False):
+    if not XSH.env.get("AUTO_CD", False):
         return False
     try:
         cmd_abspath = os.path.abspath(os.path.expanduser(cmd))
-    except (FileNotFoundError, OSError):
+    except (OSError):
         return False
     return os.path.isdir(cmd_abspath)
 
@@ -1577,7 +1630,7 @@ def subproc_arg_callback(_, match):
         path = os.path.expanduser(text)
         path_stat = os.lstat(path)  # lstat() will raise FNF if not a real file
         yieldVal, _ = color_file(path, path_stat)
-    except (FileNotFoundError, OSError):
+    except (OSError):
         pass
 
     yield (match.start(), yieldVal, text)
@@ -1599,15 +1652,15 @@ class XonshLexer(Python3Lexer):
         if not hasattr(builtins, "__xonsh__"):
             from argparse import Namespace
 
-            setattr(builtins, "__xonsh__", Namespace())
-        if not hasattr(builtins.__xonsh__, "env"):
-            setattr(builtins.__xonsh__, "env", {})
+            builtins.__xonsh__ = Namespace()
+        if not hasattr(XSH, "env"):
+            XSH.env = {}
             if ON_WINDOWS:
                 pathext = os_environ.get("PATHEXT", [".EXE", ".BAT", ".CMD"])
-                builtins.__xonsh__.env["PATHEXT"] = pathext.split(os.pathsep)
-        if not hasattr(builtins.__xonsh__, "commands_cache"):
-            setattr(builtins.__xonsh__, "commands_cache", CommandsCache())
-        _ = builtins.__xonsh__.commands_cache.all_commands  # NOQA
+                XSH.env["PATHEXT"] = pathext.split(os.pathsep)
+        if not getattr(XSH, "commands_cache", None):
+            XSH.commands_cache = CommandsCache()
+        _ = XSH.commands_cache.all_commands  # NOQA
         super().__init__(*args, **kwargs)
 
     tokens = {
@@ -1658,7 +1711,7 @@ class XonshLexer(Python3Lexer):
         ],
         "subproc": [
             include("mode_switch_brackets"),
-            (r"&&|\|\|", Operator, "subproc_start"),
+            (r"&&|\|\||\band\b|\bor\b", Operator, "subproc_start"),
             (r'"(\\\\|\\[0-7]+|\\.|[^"\\])*"', String.Double),
             (r"'(\\\\|\\[0-7]+|\\.|[^'\\])*'", String.Single),
             (r"(?<=\w|\s)!", Keyword, "subproc_macro"),
@@ -1677,7 +1730,7 @@ class XonshLexer(Python3Lexer):
         ],
     }
 
-    def get_tokens_unprocessed(self, text):
+    def get_tokens_unprocessed(self, text, **_):
         """Check first command, then call super.get_tokens_unprocessed
         with root or subproc state"""
         start = 0
